@@ -19,6 +19,8 @@ QwtPlotItem
    :members:
 """
 
+import math
+
 from qtpy.QtWidgets import (
     QWidget,
     QSizePolicy,
@@ -215,7 +217,7 @@ class AxisData(object):
         self.scaleWidget = None  # QwtScaleWidget
 
 
-class QwtPlot(QFrame, QwtPlotDict):
+class QwtPlot(QwtPlotDict, QFrame):
     """
     A 2-D plotting widget
 
@@ -247,7 +249,7 @@ class QwtPlot(QFrame, QwtPlotDict):
         plot.resize(600, 300)
         plot.show()
 
-    .. image:: /images/QwtPlot_example.png
+    .. image:: /_static/QwtPlot_example.png
 
     .. py:class:: QwtPlot([title=""], [parent=None])
 
@@ -359,17 +361,6 @@ class QwtPlot(QFrame, QwtPlotDict):
 
         qwtEnableLegendItems(self, True)
 
-    def __del__(self):
-        self.setAutoReplot(False)
-        # XXX Is is really necessary in Python? (pure transcription of C++)
-        # The following line have been commented to avoid crashing Python
-        # when exiting interpreter (Python 3 only)
-
-    #        self.detachItems(QwtPlotItem.Rtti_PlotItem, self.autoDelete())
-    #        self.__data.layout = None
-    #        self.deleteAxesData()
-    #        self.__data = None
-
     def setFlatStyle(self, state):
         """
         Set or reset the flatStyle option
@@ -583,7 +574,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).maxMajor
+            return self.__axisData[axisId].maxMajor
         else:
             return 0
 
@@ -598,7 +589,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).maxMinor
+            return self.__axisData[axisId].maxMinor
         else:
             return 0
 
@@ -639,7 +630,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).stepSize
+            return self.__axisData[axisId].stepSize
         else:
             return 0
 
@@ -989,8 +980,8 @@ class QwtPlot(QFrame, QwtPlotDict):
             # Otherwise, when tick labels are large enough, the ticks
             # may not be aligned with canvas grid.
             # See the following issues for more details:
-            # https://github.com/PierreRaybaut/guiqwt/issues/57
-            # https://github.com/PierreRaybaut/PythonQwt/issues/30
+            # https://github.com/PlotPyStack/guiqwt/issues/57
+            # https://github.com/PlotPyStack/PythonQwt/issues/30
             startDist, endDist = scaleWidget.getBorderDistHint()
             scaleWidget.setBorderDist(startDist, endDist)
 
@@ -1388,7 +1379,7 @@ class QwtPlot(QFrame, QwtPlotDict):
 
         for axisId in self.AXES:
             if margins[axisId] >= 0.0:
-                m = np.ceil(margins[axisId])
+                m = math.ceil(margins[axisId])
                 self.plotLayout().setCanvasMargin(m, axisId)
                 doUpdate = True
 
@@ -1437,10 +1428,6 @@ class QwtPlot(QFrame, QwtPlotDict):
                     QPainter.Antialiasing,
                     item.testRenderHint(QwtPlotItem.RenderAntialiased),
                 )
-                painter.setRenderHint(
-                    QPainter.HighQualityAntialiasing,
-                    item.testRenderHint(QwtPlotItem.RenderAntialiased),
-                )
                 item.draw(painter, maps[item.xAxis()], maps[item.yAxis()], canvasRect)
                 painter.restore()
 
@@ -1524,7 +1511,7 @@ class QwtPlot(QFrame, QwtPlotDict):
 
             :py:meth:`setCanvasBackground()`
         """
-        return self.canvas().palette().brush(QPalette.Normal, QPalette.Window)
+        return self.canvas().palette().brush(QPalette.Active, QPalette.Window)
 
     def axisValid(self, axis_id):
         """
