@@ -13,8 +13,6 @@ QwtPlotRenderer
    :members:
 """
 
-from __future__ import division
-
 from qwt.painter import QwtPainter
 from qwt.plot import QwtPlot
 from qwt.plot_layout import QwtPlotLayout
@@ -358,7 +356,7 @@ class QwtPlotRenderer(QObject):
         invtrans, _ok = transform.inverted()
         layoutRect = invtrans.mapRect(plotRect)
         if not (self.__data.discardFlags & self.DiscardBackground):
-            left, top, right, bottom = plot.getContentsMargins()
+            left, top, right, bottom = plot.layout().getContentsMargins()
             layoutRect.adjust(left, top, -right, -bottom)
 
         layout = plot.plotLayout()
@@ -369,7 +367,7 @@ class QwtPlotRenderer(QObject):
             if self.__data.layoutFlags & self.FrameWithScales:
                 scaleWidget = plot.axisWidget(axisId)
                 if scaleWidget:
-                    baseLineDists[axisId] = scaleWidget.margin()
+                    baseLineDists[axisId] = max(scaleWidget.getContentsMargins())
                     scaleWidget.setMargin(0)
                 if not plot.axisEnabled(axisId):
                     #  When we have a scale the frame is painted on
@@ -432,7 +430,7 @@ class QwtPlotRenderer(QObject):
         for axisId in QwtPlot.AXES:
             scaleWidget = plot.axisWidget(axisId)
             if scaleWidget:
-                baseDist = scaleWidget.margin()
+                baseDist = max(scaleWidget.getContentsMargins())
                 startDist, endDist = scaleWidget.getBorderDistHint()
                 self.renderScale(
                     plot,
